# Installation
> `npm install --save @types/datatables.net-select`

# Summary
This package contains type definitions for datatables.net-select (https://datatables.net/extensions/select/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/datatables.net-select.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/datatables.net-select/index.d.ts)
````ts
// Type definitions for datatables.net-select 1.2
// Project: https://datatables.net/extensions/select/, https://datatables.net
// Definitions by: Jared Szechy <https://github.com/szechyjs>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.4

/// <reference types="jquery" />
/// <reference types="datatables.net"/>

declare namespace DataTables {
    interface Settings {
        /*
         * Select extension options
         */
        select?: boolean | string | SelectSettings | undefined;
    }

    interface SelectSettings {
        /*
         * Indicate if the selected items will be removed when clicking outside of the table
         */
        blurable?: boolean | undefined;

        /*
         * Set the class name that will be applied to selected items
         */
        className?: string | undefined;

        /*
         * Enable / disable the display for item selection information in the table summary
         */
        info?: boolean | undefined;

        /*
         * Set which table items to select (rows, columns or cells)
         */
        items?: string | undefined;

        /*
         * Set the element selector used for mouse event capture to select items
         */
        selector?: string | undefined;

        /*
         * Set the selection style for end user interaction with the table
         */
        style?: "api" | "single" | "multi" | "os" | "multi+shift" | undefined;
    }

    interface Api {
        select: {
          /*
          * Get the current selection style applied to the table
          */
          style(): string;
          /*
          * Set the table's selection style
          */
          style(s: "api" | "single" | "multi" | "os"): Api;
        };
    }

    interface RowMethods {
      /**
       * Select a row
       */
      select(): Api;
      /**
       * Deselect a row
       */
      deselect(): Api;
    }

    interface RowsMethods {
      /**
       * Select multiple rows
       */
      select(): Api;
      /**
       * Deselect a row
       */
      deselect(): Api;
    }

    interface CellMethods {
        /**
         * Select cell
         */
        select(): Api;

        /**
         * Deselect a cell
         */
        deselect(): Api;
    }

    interface CellsMethods {
        /**
         * Select multiple cells
         */
        select(): Api;

        /**
         * Deselect cells
         */
        deselect(): Api;
    }
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 09:08:35 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery), [@types/datatables.net](https://npmjs.com/package/@types/datatables.net)
 * Global values: none

# Credits
These definitions were written by [Jared Szechy](https://github.com/szechyjs).
